API
===

.. module:: flask_restless

This part of the documentation documents all the public classes and functions
in Flask-Restless-NG.

The API Manager class
---------------------

.. autoclass:: APIManager

   .. automethod:: init_app

   .. automethod:: create_api

   .. automethod:: create_api_blueprint


Serialization helpers
---------------------

.. autoclass:: Serializer

.. autoclass:: Deserializer

.. autoclass:: SerializationException

.. autoclass:: DeserializationException


Pre- and postprocessor helpers
------------------------------

.. autoclass:: ProcessingException
